"""Main package entry point."""


def main() -> None:
    """Main function. Runs PiLibre."""
    # from pilibre.screensaver.screensaver import run_screensaver

    # run_screensaver(20)
    pass


if __name__ == "__main__":
    main()
