from rich.theme import Theme

theme = Theme(
    {
        "logo.lighter": "#ebdbb2",
        "logo.light": "#d3c5a0",
        "logo.neutral": "#bcaf8e",
        "logo.dark": "#a4997c",
        "logo.darker": "#8d836a",
        "logo.shadow": "#3c3836",
        "star.near": "#ebdbb2",
        "star.hallow": "#ebdbb2",
        "star.yellow": "yellow",
        "star.blue": "blue",
        "star.far": "#8d836a",
    }
)
